@@ -1,8 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_slv.c 3723 2007-08-25 06:14:48Z roms $ */
+/* $Id: slv_link.c 370 2004-03-22 18:47:32Z roms $ */
 
-/*  libticables2 - link cable library, a part of the TiLP project
- *  Copyright (C) 1999-2005  Romain Lievin
+/*  libticables - Ti Link Cable library, a part of the TiLP project
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,17 +25,20 @@
 #include <config.h>
 #endif
 
-#ifndef NO_CABLE_SLV
 
-#if defined(__WIN32__) && !defined(__MINGW32__)
-# define HAVE_LIBUSB
-#endif
+#if defined(__LINUX__)
+#include "linux/slv_link.c"
+#include "linux/slv_link2.c"
 
-#ifdef HAVE_LIBUSB
-# include "linux/link_slv.c"
-#endif
-#ifdef HAVE_LINUX_TICABLE_H
-# include "linux/link_dev.c"
-#endif
+#elif defined(__BSD__)
+#include "linux/slv_link.c"
+#include "linux/slv_link2.c"
 
+#elif defined(__WIN32__)
+#include "win32/slv_link.c"
+
+#elif defined(__MACOSX__)
+#include "macos/slv_link.c"
+
+#else
 #endif
