@@ -1,5 +1,8 @@
-/*  libticables - link cable library, a part of the TiLP project
- *  Copyright (C) 1999-2002  Romain Lievin
+/* Hey EMACS -*- linux-c -*- */
+/* $Id: logging.h 370 2004-03-22 18:47:32Z roms $ */
+
+/*  libticables - Ti Link Cable library, a part of the TiLP project
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,6 +22,10 @@
 #ifndef LOGGING_H
 #define LOGGING_H
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
 
 int start_logging();
@@ -29,10 +36,7 @@ int start_void();
 int log_void();
 int stop_void();
 
-/* uncomment it for enabling logging facilities */
-//#define LOGGING
-
-#ifdef LOGGING
+#ifdef LOGGING_ENABLED
 # define START_LOGGING(); start_logging();
 # define LOG_DATA(d);     log_data(d);
 # define STOP_LOGGING();  stop_logging();
