@@ -1,5 +1,8 @@
-/*  libticables - link cable library, a part of the TiLP project
- *  Copyright (C) 1999-2002  Romain Lievin
+/* Hey EMACS -*- linux-c -*- */
+/* $Id: timeout.h 651 2004-04-25 15:22:07Z roms $ */
+
+/*  libticables - Ti Link Cable library, a part of the TiLP project
+ *  Copyright (C) 1999-2004  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,8 +31,8 @@
   mine. This allowed me to find why my routines was so slow !
 */
 
-#ifndef __TIMEOUT_H__
-#define __TIMEOUT_H__
+#ifndef __TICABLE_TIMEOUT__
+#define __TICABLE_TIMEOUT__
 
 /*
   Platform independant time measurement & timeout management
@@ -40,18 +43,17 @@
 
 #if defined(__WIN32__)
 # include <windows.h>
-  typedef DWORD                         TIME;
+typedef DWORD tiTIME;
 # define  toSTART(ref)          { (ref)=GetTickCount(); }
 # define  toELAPSED(ref, max)   ( (int)(GetTickCount()-(ref)) > (100*max) )
 # define  toCURRENT(ref)        ( (float)(GetTickCount()-(ref)) / 1000 )
 
-#elif defined(__LINUX__) || defined(__MACOSX__)
+#else
 # include <time.h>
-  typedef clock_t			TIME;
-# define  toSTART(ref)		{ (ref)=clock(); }
-# define  toELAPSED(ref, max)	((clock()-(ref)) > (max/10.0*CLOCKS_PER_SEC))
-# define  toCURRENT(ref)        ( (float)(clock()-(ref))/CLOCKS_PER_SEC )
+typedef clock_t tiTIME;
+# define  toSTART(ref)	       { (ref)=clock(); }
+# define  toELAPSED(ref, max)  ( (clock()-(ref)) > ((max)/10.0*CLOCKS_PER_SEC))
+# define  toCURRENT(ref)       ( (float)(clock()-(ref))/CLOCKS_PER_SEC )
 #endif
 
 #endif
-
